@@ -1,5 +1,6 @@
-from nkdcv.Utils import stackImages, cornerRect, findContours, overlayPNG, rotateImage
+from nkdcv.Utils import stackImages, cornerRect, findContours,\
+    overlayPNG, rotateImage, putTextRect
 from nkdcv.ColorModule import ColorFinder
 from nkdcv.FPS import FPS
 from nkdcv.PIDModule import PID
-from nkdcv.PlotModule import LivePlot
\ No newline at end of file
+from nkdcv.PlotModule import LivePlot
